@@ -3,8 +3,10 @@ package Array::Each::Override;
 use strict;
 use warnings;
 
-our $VERSION = '0.04';
-use base qw<DynaLoader>;
+our $VERSION = '0.05';
+
+use XSLoader;
+XSLoader::load(__PACKAGE__, $VERSION);
 
 use Scalar::Util qw<reftype>;
 use Carp qw<croak>;
@@ -12,8 +14,6 @@ use Carp qw<croak>;
 my @FUNCTIONS = qw<each keys values>;
 my %KNOWN_FUNCTION = map { ($_ => 1, "array_$_" => 1) } @FUNCTIONS;
 
-__PACKAGE__->bootstrap($VERSION);
-
 sub import {
     my ($class, @imports) = @_;
     my $caller = caller;
